Annotation
==========

.. currentmodule:: pywwt.annotation

.. autoclass:: Annotation
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Annotation.hover_label
      ~Annotation.label
      ~Annotation.opacity
      ~Annotation.shape
      ~Annotation.tag

   .. rubric:: Methods Summary

   .. autosummary::

      ~Annotation.remove

   .. rubric:: Attributes Documentation

   .. autoattribute:: hover_label
   .. autoattribute:: label
   .. autoattribute:: opacity
   .. autoattribute:: shape
   .. autoattribute:: tag

   .. rubric:: Methods Documentation

   .. automethod:: remove
